# Make 1D spectrum from Echelle
#
# 2006.06.29, Wojtek Pych, CAMK PAN
#
# Input: List of the Echelle spectra: <spec_name>s.
#
# Input files:
# <spec_name>.ec.fits - output from 'ec> apall'
# wtab<spec_name>.txt - table of wavelenghs in the apertures
#                       (output from 'contlim')
# <spec_name>.cont.fits - continuum fit to the spectrum
#
# Output file:
# s<spec_name>.fits - 1D wavelengh calibrated, normalised spectrum
#
#****************************************************#
# dispcor and scombine                               #
#----------------------                              #
# log= no	This must be set manually in dispcor #
#****************************************************#

procedure es1(speclist)
  string speclist  {prompt="list of spectra: ", mode="ql"}
  string *wtablist {prompt="wavelengh ranges list set automaticaly"}
  int    verbose   {1,prompt="verbose level (0,1,2)"}

begin
  string  str
  string  spectrum
  string  arg
  string  name1
  string  name2
  string  name3
  real    wmin
  real    wmax
  real    cw1
  real    cw2
  bool    verb1
  bool    verb2

  verb1=no
  verb2=no
  if (verbose == 1)
  {
    verb1=yes
  }
  else if (verbose == 2)
  {
    verb1=yes
    verb2=yes
  }

  list=speclist

  while (fscan(list,spectrum) != EOF)
  {
    arg  = spectrum
    print(arg)

    name1=arg//".ec"
    name2=arg//"twav.ec"
    name3="wtab"//arg//".txt"

    wmin=100000.0
    wmax=0.0
  
    wtablist=name3
    while (fscan(wtablist, str, cw1, cw2) != EOF)
    {
      if (cw1 < wmin) wmin=cw1
      if (cw2 > wmax) wmax=cw2
    }

    if (verb1) { print "********\n dispcor1( "//name1//" )" }
    dispcor (name1,
      name2, linearize=yes, database="database", table=name3,
      w1=INDEF, w2=INDEF, dw=INDEF, nw=INDEF, flux=no, samedisp=no,
      global=no, ignoreaps=no, confirm=no, listonly=no, verbose=verb2,
      logfile="")

    name1=arg//".cont"
    name2=arg//"twav.cont"

    if (verb1) { print "********\n dispcor1( "//name1//" )" }
    dispcor (name1,
      name2, linearize=yes, database="database", table=name3,
      w1=INDEF, w2=INDEF, dw=INDEF, nw=INDEF, flux=no, samedisp=no,
      global=no, ignoreaps=no, confirm=no, listonly=no, verbose=verb2,
      logfile="")

    name1=arg//"twav.ec"
    name2=arg//"glo.ec"

    if (verb1) { print "********\n dispcor2( "//name1//" )" }

    dispcor (name1, name2, linearize=yes, database="database", table="",
      w1=wmin, w2=wmax, dw=INDEF, nw=INDEF, flux=no, samedisp=yes, global=no,
      ignoreaps=no, confirm=no, listonly=no, verbose=verb2, logfile="")

    imdel(name1, yes, verify=no, default_acti=yes)

    name1=arg//"twav.cont"
    name2=arg//"glo.cont"

    if (verb1) { print "********\n dispcor2( "//name1//" )" }

    dispcor (name1, name2, linearize=yes, database="database", table="",
      w1=wmin, w2=wmax, dw=INDEF, nw=INDEF, flux=no, samedisp=yes, global=no,
      ignoreaps=no, confirm=no, listonly=no, verbose=verb2, logfile="")

    imdel(name1, yes, verify=no, default_acti=yes)

    name1=arg//"glo.ec"
    name2=arg//"rs"

    if (verb1) { print "********\n scombine( "//name1//" )" }

    scombine (name1, name2, noutput="", logfile="logfile", apertures="",
      group="all", combine="sum", reject="none", first=no,
      w1=INDEF, w2=INDEF, dw=INDEF, nw=INDEF, scale="none", zero="none",
      weight="none", sample="", lthreshold=INDEF, hthreshold=INDEF, nlow=1,
      nhigh=1, nkeep=1, mclip=yes, lsigma=3., hsigma=3., rdnoise="0.",
      gain="1.", snoise="0.", sigscale=0.1, pclip=-0.5, grow=0, blank=0.)

    imdel(name1, yes, verify=no, default_acti=yes)

    name1=arg//"glo.cont"
    name2=arg//"contrs"

    if (verb1) { print "********\n scombine( "//name1//" )" }

    scombine (name1, name2, noutput="", logfile="logfile", apertures="",
      group="all", combine="sum", reject="none", first=no,
      w1=INDEF, w2=INDEF, dw=INDEF, nw=INDEF, scale="none", zero="none",
      weight="none", sample="", lthreshold=INDEF, hthreshold=INDEF, nlow=1,
      nhigh=1, nkeep=1, mclip=yes, lsigma=3., hsigma=3., rdnoise="0.",
      gain="1.", snoise="0.", sigscale=0.1, pclip=-0.5, grow=0, blank=0.)

    imdel(name1, yes, verify=no, default_acti=yes)

    name1=arg//"rs"
    name2=arg//"contrs"
    name3="s"//arg

    if (verb1) { print "********\n sarith" }

    imdel(name3, yes, verify=no, default_acti=yes)

    sarith (name1, "/", name2, name3, w1=INDEF, w2=INDEF, apertures="",
      bands="", beams="", apmodulus=0, reverse=no, ignoreaps=no,
      format="multispec", renumber=no, offset=0, clobber=no, merge=no,
      rebin=no, errval=0., verbose=verb2)

    print "====================="
    imheader (name3, longheader=no, userfields=yes)
    print "====================="

    imdel(name1, yes, verify=no, default_acti=yes)
    imdel(name2, yes, verify=no, default_acti=yes)
  }

end
